summaryrefslogtreecommitdiff
path: root/Master/texmf
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2010-01-08 01:38:51 +0000
committerKarl Berry <karl@freefriends.org>2010-01-08 01:38:51 +0000
commit02b6d8b30951c6d280c291863925f32a6eb84f50 (patch)
tree201c8eb47f331892b5c14c42c2413ae21c0c18ad /Master/texmf
parentf7232f0ae6eb7fc3677df2750cad3e974801e9e1 (diff)
doc fixes for generate; don't worry about
duplicated .afm files, for now anyway. git-svn-id: svn://tug.org/texlive/trunk@16635 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/texmf')
-rwxr-xr-xMaster/texmf/scripts/texlive/tlmgr.pl50
1 files changed, 28 insertions, 22 deletions
diff --git a/Master/texmf/scripts/texlive/tlmgr.pl b/Master/texmf/scripts/texlive/tlmgr.pl
index e4bcdb8b08b..1bf590ff626 100755
--- a/Master/texmf/scripts/texlive/tlmgr.pl
+++ b/Master/texmf/scripts/texlive/tlmgr.pl
@@ -3415,9 +3415,9 @@ sub check_runfiles {
# check if duplicates are different files
#
foreach my $f (@duplicates) {
- # assume tex4ht, xdy stuff is ok, and don't worry about
- # Changes/README et al.
- next if $f =~ /\.(cfg|htf|4hf|xdy)$/;
+ # assume tex4ht, xdy, afm stuff is ok, and don't worry about
+ # Changes, README et al.
+ next if $f =~ /\.(afm|cfg|4hf|htf|xdy)$/;
next if $f =~ /^(Changes|README|language\.dat|(czech|slovak)\.sty)$/;
#
my @copies = grep (/\/$f$/, @runtime_files);
@@ -4982,12 +4982,12 @@ The C<generate> action overwrites any manual changes made in the
respective files: it recreates them from scratch.
For C<fmtutil> and the language files, this is normal, and both the TeX
-Live installer and C<tlmgr> routinely call I<generate> for them.
+Live installer and C<tlmgr> routinely call C<generate> for them.
For C<updmap>, however, C<tlmgr> does I<not> use
C<generate>, because the result would be to disable all maps which have
been manually installed via S<C<updmap-sys --enable>>, e.g., for
-proprietary or local fonts. The I<generate> action only incorporates
+proprietary or local fonts. The C<generate> action only incorporates
the changes in the C<--localcfg> file mentioned below. Furthermore,
C<tlmgr> updates and maintains the final C<updmap.cfg> in
C<TEXMFSYSCONFIG> (while the other files are in C<TEXMFSYSVAR>), because
@@ -5018,7 +5018,7 @@ Local files specify entries to be disabled with a comment line like this:
where C<fmtutil.cnf> and C<updmap.cfg> use C<#>, and C<language.dat> and
C<language.def> use C<%>. In any case, the I<name> is the respective
-format name, map file name (include the C<.map> extension),or
+format name, map file name (include the C<.map> extension), or
hyphenation pattern identifier. Examples:
#!pdflatex
@@ -5029,7 +5029,9 @@ hyphenation pattern identifier. Examples:
particular items. They're just examples.)
After such a disabling line, the local file can include another entry
-for the same item, if a different definition is desired.
+for the same item, if a different definition is desired. In general,
+except for the special disabling lines, the local files follow the same
+syntax as the master files.
The form C<generate language> recreates both the C<language.dat> and the
C<language.def> files, while the forms with extension recreates only
@@ -5042,7 +5044,9 @@ C<dvipdfmDownloadBase14>. The defaults for these as set in
C<updmap-hdr.cfg> are usually fine. If you want to change them, you can
include changed settings for any or all of these five options in your
C<updmap-local.cfg> file and they will be respected by C<generate
-updmap>.
+updmap>, for example:
+
+ dvipsDownloadBase35 true
Options:
@@ -5065,8 +5069,10 @@ location in C<TEXMFLOCAL>).
=item B<--rebuild-sys>
-makes tlmgr call C<updmap-sys> after (re-)generating the updmap.cfg
-file. This is necessary to actually make the changes take effect.
+tells tlmgr to call C<updmap-sys> after (re-)generating the C<updmap.cfg>
+file. This is necessary to actually make the changes take effect. it
+is not done by default because often multiple font changes are made in
+succession, and running C<updmap> is a lengthy process.
=back
@@ -5116,18 +5122,18 @@ Furthermore is allows to quit C<tlmgr>.
=item B<Options>
-Provides access to three groups of options, B<General> (for almost all
-options), B<Paper> (configuration of default paper sizes),
-B<Architectures> (only on Unix, configuration of the supported/installed
-architectures), as well as a toggle to turn on and off Debug mode.
+Provides access to three groups of options, I<General> (for almost all
+options), I<Paper> (configuration of default paper sizes),
+I<Architectures> (only on Unix, configuration of the supported/installed
+architectures), as well as a toggle to turn on and off debugging mode.
=item B<Actions>
-Provides access to some useful items, like updating the filename database
-(ls-R, mktexlsr, texhash), rebuilding of all formats (fmtutil-sys --all),
-updating the font map database (updmap-sys), and handling of symbolic
-links in system directories (only Unix), as well as removal of the
-full TeX Live installation (only Unix).
+Provides access to a variety of items, such as updating the filename
+database (aka ls-R, mktexlsr, texhash), rebuilding of all formats
+(C<fmtutil-sys --all>), updating the font map database (C<updmap-sys>),
+and handling of symbolic links in system directories (only Unix), as
+well as removal of the full TeX Live installation (only Unix).
=item B<Help>
@@ -5138,8 +5144,8 @@ license.
=head2 Main display
-The main display lists all packages, installed and - if a repository is
-loaded - also those that are available but not installed.
+The main display lists all packages, installed and, if a repository is
+loaded, also those that are available but not installed.
Each line of the package list contains of the following items:
@@ -5242,7 +5248,7 @@ packages).
=item Backup
makes a backup of the selected packages, acts like C<tlmgr backup>. This
-action needs the options B<backupdir> set (see Options -> General).
+action needs the option C<backupdir> set (see Options -> General).
=back